@@ -249,7 +249,7 @@ class InvenTreeAPI(object):
         if response is None:
             return False
 
-        print(response.status_code, response.text)
+        logging.debug(response.status_code, response.text)
 
     def post(self, url, data, files=None, **kwargs):
         """ Perform a POST request. Used to create a new record in the database.
@@ -273,14 +273,19 @@ class InvenTreeAPI(object):
         response = requests.post(url, data=data, headers=headers, auth=auth, files=files, **kwargs)
 
         if response is None:
-            return False
+            return None
 
-        if response.status_code in [200, 201]:
-            return True
-        else:
+        if response.status_code not in [200, 201]:
             logging.error("POST request failed at '{url}' - {status}".format(url=url, status=response.status_code))
             logging.error(response.text)
-            return False
+        
+        try:
+            data = json.loads(response.text)
+        except json.decoder.JSONDecodeError:
+            logging.error("Error decoding JSON response - '{url}'".format(url=url))
+            return None
+
+        return data
 
     def put(self, url, data, **kwargs):
         """ Perform a PUT request. Used to update existing records in the database.
@@ -301,11 +306,34 @@ class InvenTreeAPI(object):
         if response is None:
             return None
         
-        if response.status_code == 200:
-            return True
-        else:
+        if response.status_code not in [200, 201]:
             logging.error("PUT request failed at '{url}' - {status}".format(url=url, status=response.status_code))
-            return False
+            return None
+
+        try:
+            data = json.loads(response.text)
+        except json.decoder.JSONDecodeError:
+            logging.error("Error decoding JSON response - '{url}'".format(url=url))
+            return None
+
+        return data
+
+    def put_image(self, url, data, files):
+        headers = {}
+
+        if self.use_token_auth and self.token:
+            headers['AUTHORIZATION'] = 'Token {t}'.format(t=self.token)
+            auth = None
+        else:
+            auth = self.auth
+
+        url = self.clean_url(url)
+        response = requests.put(url, data=data, files=files, headers=headers, auth=auth)
+
+        if response.status_code not in [200, 201]:
+            return None
+
+        return data
 
     def get(self, url, **kwargs):
         """ Perform a GET request
