@@ -3,14 +3,13 @@
 import os
 import logging
 
-INVENTREE_PYTHON_VERSION = "0.0.4"
+INVENTREE_PYTHON_VERSION = "0.1.0"
 
 
 class InventreeObject():
     """ Base class for an InvenTree object """
 
     URL = ""
-    FILTERS = []
 
     def __init__(self, api, pk=None, data={}):
         """ Instantiate this InvenTree object.
@@ -24,7 +23,7 @@ class InventreeObject():
         # If the pk is not explicitly provided,
         # extract it from the provided dataset
         if pk is None:
-            pk = data['pk']
+            pk = data.get('pk', None)
 
         self._url = "{url}/{pk}/".format(url=self.URL, pk=pk)
         self._api = api
@@ -37,7 +36,7 @@ class InventreeObject():
     @property
     def pk(self):
         """ Convenience method for accessing primary-key field """
-        return self['pk']
+        return self._data.get('pk', None)
 
     @classmethod
     def create(cls, api, data, **kwargs):
@@ -47,7 +46,13 @@ class InventreeObject():
         if 'pk' in data.keys():
             data.pop('pk')
 
-        api.post(cls.URL, data)
+        response = api.post(cls.URL, data)
+        
+        if response is None:
+            logging.error("Error creating new object")
+            return None
+
+        return cls(api, data=response)
 
     @classmethod
     def list(cls, api, **kwargs):
@@ -56,15 +61,10 @@ class InventreeObject():
         Requires:
 
         URL - Base URL
-        FILTERS - List of available query filter params
         """
 
         # Dict of query params to send to the API
-        params = {}
-
-        for arg in cls.FILTERS:
-            if kwargs.get(arg, None):
-                params[arg] = kwargs[arg]
+        params = kwargs
 
         response = api.get(cls.URL, params=params, **kwargs)
 
@@ -96,6 +96,12 @@ class InventreeObject():
             if data is not None:
                 self._data = data
 
+    def __getattr__(self, name):
+        if name in self._data.keys():
+            return self._data[name]
+        else:
+            return super().__getattr__(name)
+
     def __getitem__(self, name):
         if name in self._data.keys():
             return self._data[name]
@@ -150,7 +156,6 @@ class Currency(InventreeObject):
 class Parameter(InventreeObject):
     """class representing the Parameter database model """
     URL = 'part/parameter'
-    FILTERS = ['part']
 
     def getunits(self):
         """ Get the dimension and units for this parameter """
