@@ -1,32 +1,32 @@
 # -*- coding: utf-8 -*-
 
-from inventree import base
+import inventree.base
 
 
-class Company(base.InventreeObject):
+class Company(inventree.base.InventreeObject):
     """ Class representing the Company database model """
 
     URL = 'company'
-    FILTERS = ['is_supplier', 'is_customer']
 
-    def get_supplier_parts(self):
-        return SupplierPart.list(self._api, part=self.pk)
+    def getSuppliedParts(self):
+        return SupplierPart.list(self._api, supplier=self.pk)
+
+    def getManufacturedParts(self):
+        return SupplierPart.list(self._api, manufacturer=self.pk)
 
 
-class SupplierPart(base.InventreeObject):
+class SupplierPart(inventree.base.InventreeObject):
     """ Class representing the SupplierPart database model """
 
     URL = 'company/part'
-    FILTERS = ['part', 'supplier']
 
-    def get_price_breaks(self):
+    def getPriceBreaks(self):
         """ Get a list of price break objects for this SupplierPart """
 
         return SupplierPriceBreak.list(self._api, part=self.pk)
 
 
-class SupplierPriceBreak(base.InventreeObject):
+class SupplierPriceBreak(inventree.base.InventreeObject):
     """ Class representing the SupplierPriceBreak database model """
 
     URL = 'company/price-break/'
-    FILTERS = ['part', 'currency']
